Description Usage Arguments Author(s) Examples
This Function has a two features . At first converts every single element of the vector to a UTF-8 encoding and second changes all the greek letters with a tone to characters without tones
1 |
x |
A string or data frame you want to convert to UTF-8 and change toned letters |
Nick Krystallis
1 2 3 4 5 6 7 8 | ##---- Should be DIRECTLY executable !! ----
##-- ==> Define data, use random,
##-- or do help(data=index) for the standard data sets.
## The function is currently defined as
function (x)
{
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.